from distutils.core import setup

setup(
    name='Verilog_VCD',
    version='1.06',
    author='Sameer Gauria',
    author_email='sgauria+python@gmail.com',
    packages=['Verilog_VCD'],
    url='http://pypi.python.org/pypi/Verilog_VCD/',
    description='Module to Parse VCD (Value-Change-Dump) files',
    long_description=open('README.txt').read(),
)
